summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/kopetewindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/kopetewindow.h')
-rw-r--r--kopete/kopete/kopetewindow.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/kopete/kopete/kopetewindow.h b/kopete/kopete/kopetewindow.h
index cc466883..158b2805 100644
--- a/kopete/kopete/kopetewindow.h
+++ b/kopete/kopete/kopetewindow.h
@@ -20,10 +20,10 @@
#ifndef KOPETEWINDOW_H
#define KOPETEWINDOW_H
-#include <qptrdict.h>
+#include <tqptrdict.h>
#include <kmainwindow.h>
-#include <qlabel.h>
+#include <tqlabel.h>
class QHBox;
class QTimer;
@@ -63,15 +63,15 @@ class KopeteWindow : public KMainWindow
Q_OBJECT
public:
- KopeteWindow ( QWidget *parent = 0, const char *name = 0 );
+ KopeteWindow ( TQWidget *parent = 0, const char *name = 0 );
~KopeteWindow();
- virtual bool eventFilter( QObject* o, QEvent* e );
+ virtual bool eventFilter( TQObject* o, TQEvent* e );
protected:
- virtual void closeEvent( QCloseEvent *ev );
- virtual void leaveEvent( QEvent* ev );
- virtual void showEvent( QShowEvent* ev );
+ virtual void closeEvent( TQCloseEvent *ev );
+ virtual void leaveEvent( TQEvent* ev );
+ virtual void showEvent( TQShowEvent* ev );
private slots:
void showMenubar();
@@ -89,7 +89,7 @@ private slots:
/* show the global status message selector menu
*/
- void setStatusMessage( const QString & );
+ void setStatusMessage( const TQString & );
/**
* Checks if the mousecursor is in the contact list.
@@ -146,13 +146,13 @@ private slots:
/**
* Show a context menu for a protocol
*/
-// void slotProtocolStatusIconRightClicked( Kopete::Protocol *proto, const QPoint &p );
+// void slotProtocolStatusIconRightClicked( Kopete::Protocol *proto, const TQPoint &p );
/**
* Show a context menu for an account
*/
void slotAccountStatusIconRightClicked( Kopete::Account *a,
- const QPoint &p );
+ const TQPoint &p );
void slotTrayAboutToShowMenu(KPopupMenu *);
@@ -183,15 +183,15 @@ private slots:
/**
* Show the set global status message menu when clicking on the icon in the status bar.
*/
- void slotGlobalStatusMessageIconClicked( const QPoint &position );
+ void slotGlobalStatusMessageIconClicked( const TQPoint &position );
/**
* Extracts protocolId and accountId from the single QString argument signalled by a QSignalMapper,
* get the account, and call showAddContactDialog.
* @param accountIdentifer QString of protocolId and accountId, concatenated with QChar( 0xE000 )
* We need both to uniquely identify an account, but QSignalMapper only emits one QString.
*/
- void slotAddContactDialogInternal( const QString & accountIdentifier );
+ void slotAddContactDialogInternal( const TQString & accountIdentifier );
public:
KopeteContactListView *contactlist;
@@ -238,27 +238,27 @@ private:
int docked;
bool hidden;
int deskRight;
- QPoint position;
- QHBox *m_statusBarWidget;
+ TQPoint position;
+ TQHBox *m_statusBarWidget;
KopeteSystemTray *m_tray;
bool m_autoHide;
unsigned int m_autoHideTimeout;
- QTimer* m_autoHideTimer;
- QSignalMapper* addContactMapper;
+ TQTimer* m_autoHideTimer;
+ TQSignalMapper* addContactMapper;
KopetePluginConfig *m_pluginConfig;
/**
* This is really a dictionary of KopeteAccountStatusBarIcon objects, but
* QPtrDict requires a full class definition to be known to make
* that work. And since I don't want to include that whole file here,
* use QObject instead.
*/
- QPtrDict<QObject> m_accountStatusBarIcons;
+ TQPtrDict<TQObject> m_accountStatusBarIcons;
KSqueezedTextLabel * m_globalStatusMessage;
KPopupMenu * m_globalStatusMessageMenu;
- QLineEdit * m_newMessageEdit;
- QString m_globalStatusMessageStored;
+ TQLineEdit * m_newMessageEdit;
+ TQString m_globalStatusMessageStored;
};
@@ -266,13 +266,13 @@ class GlobalStatusMessageIconLabel : public QLabel
{
Q_OBJECT
public:
- GlobalStatusMessageIconLabel(QWidget *parent = 0, const char *name = 0);
+ GlobalStatusMessageIconLabel(TQWidget *parent = 0, const char *name = 0);
protected:
- void mouseReleaseEvent(QMouseEvent *event);
+ void mouseReleaseEvent(TQMouseEvent *event);
signals:
- void iconClicked(const QPoint &position);
+ void iconClicked(const TQPoint &position);
};
@@ -183,15 +183,15 @@ private slots:
/**
- * Extracts protocolId and accountId from the single QString argument signalled by a QSignalMapper,
+ * Extracts protocolId and accountId from the single TQString argument signalled by a TQSignalMapper,
* get the account, and call showAddContactDialog.
@@ -183,15 +183,15 @@ private slots:
* get the account, and call showAddContactDialog.
- * @param accountIdentifer QString of protocolId and accountId, concatenated with QChar( 0xE000 )
- * We need both to uniquely identify an account, but QSignalMapper only emits one QString.
+ * @param accountIdentifer TQString of protocolId and accountId, concatenated with TQChar( 0xE000 )
+ * We need both to uniquely identify an account, but TQSignalMapper only emits one TQString.
*/
@@ -238,27 +238,27 @@ private:
/**
* This is really a dictionary of KopeteAccountStatusBarIcon objects, but
- * QPtrDict requires a full class definition to be known to make
+ * TQPtrDict requires a full class definition to be known to make
* that work. And since I don't want to include that whole file here,
@@ -238,27 +238,27 @@ private:
* that work. And since I don't want to include that whole file here,
- * use QObject instead.
+ * use TQObject instead.
*/